From e6686963ba1140ad6d8d10f7f302d1adf6b8740f Mon Sep 17 00:00:00 2001
From: Jakob Linskeseder <jakob@linskeseder.com>
Date: Fri, 20 May 2022 22:40:36 +0200
Subject: [PATCH] Use `@handlebars/parser` v2
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit

We have to remove `--failAfterWarnings` from our Rollup integration-test,
because Typescript, when targeting es5, will use global `this` for transpilation.
Rollup warns about this, since it replaces `this` with `undefined`:

```
src/index.js → dist/bundle.js...
(!) `this` has been rewritten to `undefined`
https://rollupjs.org/guide/en/#error-this-is-undefined
../../../node_modules/@handlebars/parser/dist/esm/printer.js
1: var __spreadArrays = (this && this.__spreadArrays) || function () {}
```

See https://github.com/handlebars-lang/handlebars-parser/releases/tag/v2.0.0
---
 package-lock.json                          | 14 +++++++-------
 package.json                               |  2 +-
 tests/integration/rollup-test/package.json |  2 +-
 3 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/package-lock.json b/package-lock.json
index da1138f4..35076066 100644
--- a/package-lock.json
+++ b/package-lock.json
@@ -9,7 +9,7 @@
       "version": "5.0.0-alpha.1",
       "license": "MIT",
       "dependencies": {
-        "@handlebars/parser": "^1.1.0",
+        "@handlebars/parser": "^2.1.0",
         "neo-async": "^2.6.2",
         "source-map": "^0.6.1",
         "yargs": "^16.2.0"
@@ -716,9 +716,9 @@
       }
     },
     "node_modules/@handlebars/parser": {
-      "version": "1.1.0",
-      "resolved": "https://registry.npmjs.org/@handlebars/parser/-/parser-1.1.0.tgz",
-      "integrity": "sha512-rR7tJoSwJ2eooOpYGxGGW95sLq6GXUaS1UtWvN7pei6n2/okYvCGld9vsUTvkl2migxbkszsycwtMf/GEc1k1A=="
+      "version": "2.1.0",
+      "resolved": "https://registry.npmjs.org/@handlebars/parser/-/parser-2.1.0.tgz",
+      "integrity": "sha512-R14NuNaSKZ6eE9y4t0fg/1f8iKd5ZJtSOTIseGFzXINTV17XffhLG2Y0CvdKOgyVQ7+UnXi89YGzRo/xsgwHIA=="
     },
     "node_modules/@humanwhocodes/config-array": {
       "version": "0.10.7",
@@ -15127,9 +15127,9 @@
       }
     },
     "@handlebars/parser": {
-      "version": "1.1.0",
-      "resolved": "https://registry.npmjs.org/@handlebars/parser/-/parser-1.1.0.tgz",
-      "integrity": "sha512-rR7tJoSwJ2eooOpYGxGGW95sLq6GXUaS1UtWvN7pei6n2/okYvCGld9vsUTvkl2migxbkszsycwtMf/GEc1k1A=="
+      "version": "2.1.0",
+      "resolved": "https://registry.npmjs.org/@handlebars/parser/-/parser-2.1.0.tgz",
+      "integrity": "sha512-R14NuNaSKZ6eE9y4t0fg/1f8iKd5ZJtSOTIseGFzXINTV17XffhLG2Y0CvdKOgyVQ7+UnXi89YGzRo/xsgwHIA=="
     },
     "@humanwhocodes/config-array": {
       "version": "0.10.7",
diff --git a/package.json b/package.json
index 7351ee8d..8d732c21 100644
--- a/package.json
+++ b/package.json
@@ -20,7 +20,7 @@
     "node": ">=12"
   },
   "dependencies": {
-    "@handlebars/parser": "^1.1.0",
+    "@handlebars/parser": "^2.1.0",
     "neo-async": "^2.6.2",
     "source-map": "^0.6.1",
     "yargs": "^16.2.0"
diff --git a/tests/integration/rollup-test/package.json b/tests/integration/rollup-test/package.json
index 18807a7c..dd0a735d 100644
--- a/tests/integration/rollup-test/package.json
+++ b/tests/integration/rollup-test/package.json
@@ -3,7 +3,7 @@
   "description": "Various tests with Handlebars and rollup",
   "version": "1.0.0",
   "scripts": {
-    "build": "rollup --config rollup.config.js --failAfterWarnings"
+    "build": "rollup --config rollup.config.js"
   },
   "private": true,
   "devDependencies": {
